###################################################
### chunk number 1: 
###################################################
library(OrgMassSpecR)


###################################################
### chunk number 2: 
###################################################
MonoisotopicMass(formula = list(C=14, H=8, Cl=4))


###################################################
### chunk number 3: 
###################################################
MonoisotopicMass(formula = list(C=14, H=8, Cl=3))
MonoisotopicMass(formula = list(C=14, H=8, Cl=2))
# etc, ...


###################################################
### chunk number 4: 
###################################################
MonoisotopicMass(formula = list(C=2, H=8, Cl=4, x = 12), 
                 isotopes = list(x = 13.0033548378))


###################################################
### chunk number 5: 
###################################################
dde.dist <- IsotopicDistribution(formula = list(C=14, H=8, Cl=4))
dde.dist


###################################################
### chunk number 6: 
###################################################
# plot
library(lattice)
print(xyplot(percent ~ mz,
  data = dde.dist,
  type = "h",
  xlab = "m/z",
  ylab = "intensity (%)",
  main = "Isotopic Distribution, DDE")
)


###################################################
### chunk number 7: 
###################################################
hsa <- Digest(example.sequence)
head(hsa)


###################################################
### chunk number 8: 
###################################################
hsa.sub <- subset(hsa, nchar(hsa$peptide) >= 5 & nchar(hsa$peptide) <= 12)
head(hsa.sub)


###################################################
### chunk number 9: 
###################################################
transitions <- FragmentPeptide(c("YLYEIAR", "AEFAEVSK"))
head(transitions)


###################################################
### chunk number 10: 
###################################################
c13.labeled <- FragmentPeptide("YLYEIAr", custom = list(code = "r", 
  mass = MonoisotopicMass(formula = list(C=6, H=12, N=4, O=1), 
                          isotopes = list(C=13.0033548378))))
head(c13.labeled)


###################################################
### chunk number 11: 
###################################################
n15.labeled <- FragmentPeptide("YLYEIAR", N15 = TRUE)
head(n15.labeled)


###################################################
### chunk number 12: 
###################################################
theoretical.dist <- IsotopicDistributionN("YEVQGEVFTKPQLWP", incorp = 0.99)
print(xyplot(percent ~ mz,
  data = theoretical.dist,
  type = "h",
  xlab = "m/z",
  ylab = "intensity (%)",
  main = "Theoretical Isotopic Distribution, YEVQGEVFTKPQLWP, 99% 15N")
)


###################################################
### chunk number 13: 
###################################################
example.spectrum.labeled$percent <- with(example.spectrum.labeled, 
  intensity / max(intensity) * 100)
print(xyplot(percent ~ mz,
  data = example.spectrum.labeled,
  type = "l",
  xlab = "m/z",
  ylab = "intensity (%)",
  main = "Measured Isotopic Distribution, YEVQGEVFTKPQLWP")
)


